@@ -29,16 +29,16 @@ File*       fileio_load (const gchar *fname, GError **err);
 
 gboolean    fileio_save (Ignuit *ig, const gchar *fname, GError **err);
 
-File*       fileio_import_sv (const gchar *fname,
-                const gchar *sep, GError **err);
+File*       fileio_import_csv (const gchar *fname,
+                gchar delimiter, GError **err);
 
-File*       fileio_import (Ignuit *ig, const gchar *fname,
+File*       fileio_import_xml (Ignuit *ig, const gchar *fname,
                 const gchar *filter, GError **err);
 
-gboolean    fileio_export_sv (File *f, const gchar *fname,
-                const gchar *sep, GError **err);
+gboolean    fileio_export_csv (File *f, const gchar *fname,
+                gchar delimiter, GError **err);
 
-gboolean    fileio_export (Ignuit *ig, const gchar *fname,
+gboolean    fileio_export_xml (Ignuit *ig, const gchar *fname,
                 const gchar *filter, GError **err);
 
 
